@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2022 Vaclav Slavik
+ *  Copyright (C) 1999-2023 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -148,17 +148,30 @@ typedef std::vector<POCatalogDeletedData> POCatalogDeletedDataArray;
 
 class POCatalog : public Catalog
 {
+protected:
+    /// Default ctor. Creates empty catalog, you have to call Load.
+    explicit POCatalog(Type type);
+
+    /// Ctor that loads the catalog from \a po_file with Load.
+    /// \a flags is CreationFlags combination.
+    explicit POCatalog(const wxString& po_file, int flags = 0);
+
+    void PostCreation() override;
+
 public:
     // Common wrapping values
     static const int NO_WRAPPING = -1;
     static const int DEFAULT_WRAPPING = -2;
 
-    /// Default ctor. Creates empty catalog, you have to call Load.
-    explicit POCatalog(Type type = Type::PO);
+    static POCatalogPtr Create(Type type)
+    {
+        return std::dynamic_pointer_cast<POCatalog>(Catalog::Create(type));
+    }
 
-    /// Ctor that loads the catalog from \a po_file with Load.
-    /// \a flags is CreationFlags combination.
-    explicit POCatalog(const wxString& po_file, int flags = 0);
+    static POCatalogPtr Create(const wxString& filename, int flags = 0)
+    {
+        return std::dynamic_pointer_cast<POCatalog>(Catalog::Create(filename, flags));
+    }
 
     ~POCatalog() {}
 
@@ -167,19 +180,29 @@ public:
     static bool CanLoadFile(const wxString& extension);
     wxString GetPreferredExtension() const override;
 
+    unsigned GetPluralFormsCount() const override;
+    void SetLanguage(Language lang) override;
+
     bool Save(const wxString& po_file, bool save_mo,
               ValidationResults& validation_results,
               CompilationStatus& mo_compilation_status) override;
 
     std::string SaveToBuffer() override;
 
-    ValidationResults Validate(bool wasJustLoaded) override;
+    ValidationResults Validate(const wxString& fileWithSameContent) override;
 
     /// Compiles the catalog into binary MO file.
     bool CompileToMO(const wxString& mo_file,
                      ValidationResults& validation_results,
                      CompilationStatus& mo_compilation_status);
 
+    /// Returns true if Plural-Forms header doesn't match plural forms
+    /// usage in catalog items
+    bool HasWrongPluralFormsCount() const;
+
+    /// Does this catalog have any items with plural forms?
+    bool HasPluralItems() const { return m_hasPluralItems; }
+
     /// Detect a particular common breakage of catalogs.
     bool HasDuplicateItems() const;
 
@@ -207,7 +230,7 @@ protected:
 
         @param flags CreationFlags combination.
      */
-    bool Load(const wxString& po_file, int flags = 0);
+    void Load(const wxString& po_file, int flags = 0);
 
     void Clear();
 
@@ -225,7 +248,7 @@ protected:
     /// Fix commonly encountered fixable problems with loaded files
     void FixupCommonIssues();
 
-    ValidationResults DoValidate(const wxString& po_file);
+    void ValidateWithMsgfmt(ValidationResults& res, const wxString& po_file);
     bool DoSaveOnly(const wxString& po_file, wxTextFileType crlf);
     bool DoSaveOnly(wxTextBuffer& f, wxTextFileType crlf);
 
@@ -244,8 +267,10 @@ protected:
 
     wxTextFileType m_fileCRLF;
     int m_fileWrappingWidth;
+    bool m_hasPluralItems = false;
 
     friend class POLoadParser;
+    friend class Catalog;
 };
 
 
