@@ -39,6 +39,9 @@
 class WXDLLIMPEXP_FWD_BASE wxConfigBase;
 class WXDLLIMPEXP_FWD_BASE wxSingleInstanceChecker;
 
+#if defined(HAVE_HTTP_CLIENT) && (defined(__WXMSW__) || defined(__WXOSX__) || defined(SNAPCRAFT))
+    #define SUPPORTS_OTA_UPDATES
+#endif
 
 /// wxApp for use with
 class PoeditApp : public wxApp, public MenusManager
@@ -56,8 +59,11 @@ class PoeditApp : public wxApp, public MenusManager
 
         wxLayoutDirection GetLayoutDirection() const override;
 
+        static wxString GetCacheDir(const wxString& category);
+
         /// Returns Poedit version string.
-        wxString GetAppVersion() const;
+        wxString GetAppVersion() const; // e.g. "3.4.2"
+        wxString GetMajorAppVersion() const; // e.g. "3.4"
         wxString GetAppBuildNumber() const;
         bool CheckForBetaUpdates() const;
 
@@ -102,6 +108,9 @@ class PoeditApp : public wxApp, public MenusManager
         void HandleCustomURI(const wxString& uri);
 
         void SetupLanguage();
+#ifdef SUPPORTS_OTA_UPDATES
+        void SetupOTALanguageUpdate(wxTranslations *trans, const wxString& lang);
+#endif
 
         // App-global menu commands:
         void OnNewFromScratch(wxCommandEvent& event);
